@@ -4,14 +4,17 @@ import os
 
 BASE_DIR: str = os.path.dirname((os.path.dirname(__file__)))
 
-DEFAULT_BLOCKING: bool = False
-
-DEFAULT_CONFIGURATION_PATH: str = os.path.join('/etc', 'kameleoon', 'client-python.yaml')
+DEFAULT_CONFIGURATION_PATH: str = os.path.join(
+    "/etc", "kameleoon", "client-python.yaml"
+)
 
 DEBUG: bool = True
 
 DEFAULT_TIMEOUT_MILLISECONDS: int = 5000  # milli-seconds
-DEFAULT_TIMEOUT_SECONDS: float = DEFAULT_TIMEOUT_MILLISECONDS / 1000  # seconds
+MILLISECONDS_IN_SECOND: int = 1000
+DEFAULT_TIMEOUT_SECONDS: float = (
+    DEFAULT_TIMEOUT_MILLISECONDS / MILLISECONDS_IN_SECOND
+)  # seconds
 
 DEFAULT_MILLISECONDS_BETWEEN_TARGETING_DATA_UPDATE: int = 1800000
 
@@ -21,12 +24,14 @@ TARGETING_DATA_MAXIMUM_SIZE_BYTES = 500
 
 DEFAULT_VISITOR_DATA_MAXIMUM_SIZE = 500  # Mb
 
-KAMELEOON_COOKIE_NAME = 'kameleoonVisitorCode'
+KAMELEOON_COOKIE_NAME = "kameleoonVisitorCode"
 
 EXPIRE_DAYS = 380
 
 MAX_AGE = 32832000
 
+USER_AGENT_MAX_COUNT = 100_000
+
 KAMELEOON_COOKIE_VALUE_LENGTH = 16
 
 KAMELEOON_VISITOR_CODE_LENGTH = 255
