@@ -1,12 +1,12 @@
+"""Helper methods for running functions in multi-threading"""
 
 import threading
 from typing import Any, List
 
 
-def run_in_threads_if_required(background_thread: bool,
-                               func,
-                               args: List[Any],
-                               thread_name: str):
+def run_in_threads_if_required(
+    background_thread: bool, func, args: List[Any], thread_name: str
+):
     """
     it's wrapper function which run the `func`
     in another thread if multi_threading option is True
@@ -27,4 +27,4 @@ def run_in_threads_if_required(background_thread: bool,
         thread.setName(thread_name)
         thread.start()
     else:
-        func(*args)
\ No newline at end of file
+        func(*args)
