@@ -1,6 +1,6 @@
-DataType = {
-    "CUSTOM": "CUSTOM"
-}
+""" Constants """
+
+DataType = {"CUSTOM": "CUSTOM"}
 
 Operator = {
     "UNDEFINED": "UNDEFINED",
@@ -13,5 +13,5 @@ Operator = {
     "IS_TRUE": "TRUE",
     "IS_FALSE": "FALSE",
     "AMONG_VALUES": "AMONG_VALUES",
-    "ANY": "ANY"
+    "ANY": "ANY",
 }
