@@ -1,3 +1,4 @@
+"""CustomData condition"""
 import re
 from typing import Any, Union, Dict
 
@@ -5,24 +6,40 @@ from kameleoon.exceptions import NotFoundError, KameleoonException
 from kameleoon.targeting.condition import Condition
 from kameleoon.targeting.conditions.constants import Operator, DataType
 
-__all__ = ["CustomDatum", ]
+__all__ = [
+    "CustomDatum",
+]
+
 
 class CustomDatum(Condition):
+    """CustomDatum represents a Custom Data condition from back-office"""
+
     def __init__(self, json_condition: Dict[str, Union[str, Any]]):
         super().__init__(json_condition)
-        if 'customDataIndex' not in json_condition or json_condition['customDataIndex'] is None:
-            raise NotFoundError('customDataIndex')
-        self.index = json_condition['customDataIndex']
-        if 'valueMatchType' not in json_condition or json_condition['valueMatchType'] is None:
-            raise NotFoundError('valueMatchType')
-        self.operator = json_condition['valueMatchType']
-        if 'value' in json_condition and json_condition['value'] is not None:
-            self.value = json_condition['value']
+        if (
+            "customDataIndex" not in json_condition
+            or json_condition["customDataIndex"] is None
+        ):
+            raise NotFoundError("customDataIndex")
+        self.index = json_condition["customDataIndex"]
+        if (
+            "valueMatchType" not in json_condition
+            or json_condition["valueMatchType"] is None
+        ):
+            raise NotFoundError("valueMatchType")
+        self.operator = json_condition["valueMatchType"]
+        if "value" in json_condition and json_condition["value"] is not None:
+            self.value = json_condition["value"]
 
-    def check(self, datas) -> bool:
+    # pylint: disable=R0912
+    def check(self, datas) -> bool:  # noqa: C901
         is_targeted = False
         try:
-            custom_data = [x for x in datas if x.instance == DataType["CUSTOM"] and x.id == self.index][-1]
+            custom_data = [
+                x
+                for x in datas
+                if x.instance == DataType["CUSTOM"] and x.id == self.index
+            ][-1]
         except IndexError:
             custom_data = None
         if not custom_data:
@@ -50,14 +67,24 @@ class CustomDatum(Condition):
                 if float(custom_data.value) < float(self.value):
                     is_targeted = True
             elif self.operator == Operator["IS_TRUE"]:
-                if custom_data.value == 'true':
+                if custom_data.value == "true":
                     is_targeted = True
             elif self.operator == Operator["IS_FALSE"]:
-                if custom_data.value == 'false':
+                if custom_data.value == "false":
                     is_targeted = True
             elif self.operator == Operator["AMONG_VALUES"]:
-                allMatches = re.findall('"([^"]*)"', self.value)
-                is_targeted = len(list(filter(lambda element: element == custom_data.value, allMatches))) > 0
+                all_matches = re.findall('"([^"]*)"', self.value)
+                is_targeted = (
+                    len(
+                        list(
+                            filter(
+                                lambda element: element == custom_data.value,
+                                all_matches,
+                            )
+                        )
+                    )
+                    > 0
+                )
             else:
                 raise KameleoonException(f"Undefined operator {self.operator}")
 
